@@ -3,6 +3,7 @@ from __future__ import unicode_literals
 from pandas import DataFrame
 from portalocker import Lock as Open
 from django.utils.crypto import get_random_string
+from xml.sax.saxutils import escape
 
 import xml.etree.ElementTree as ET
 import datetime
@@ -76,14 +77,16 @@ class XML(object):
         if not isinstance(dataframe, DataFrame):
             raise ValueError("'dataframe' %r is not an instance of DataFrame from pandas" % dataframe)
 
-        while os.path.exists(self.xml_file):
+        xml_file = self.xml_file
+
+        while os.path.exists(xml_file):
             uid = get_random_string(length=16,
                                     allowed_chars=u'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789')
             date = datetime.datetime.now()
-            self.xml_file = os.path.join(os.path.dirname(self.xml_file),
-                                         '%s-%s-%s_%s.xml' % (date.year, date.month, date.day, uid))
+            xml_file = os.path.join(os.path.dirname(xml_file),
+                                    '%s-%s-%s_%s.xml' % (date.year, date.month, date.day, uid))
 
-        with Open(self.xml_file, 'w') as xmlfile:
+        with Open(xml_file, 'w') as xmlfile:
             xmlfile.write('<?xml version="1.0" encoding="UTF-8"?>\n')
             xmlfile.write('<records>\n')
             xmlfile.write(
@@ -152,5 +155,5 @@ class XML(object):
 
     @staticmethod
     def __handle_illegals(data):
-        return data.replace('<', '&lt;').replace('>', '&gt;').replace('&', '&amp;').replace('"', '&quot;') \
-            .replace("'", '&apos;').replace("’", '&apos;')
+        return str(escape(text)).replace('"', '&quot;').replace("'", '&apos;').replace("’", '&apos;')\
+            .replace(chr(160), ' ')
